@@ -30,12 +30,9 @@
 class MixDevice;
 class ViewBase;
 
-// KDE
-class KAction;
-class KComboBox;
-
 // Qt
 class QBoxLayout;
+class QComboBox;
 class QLabel;
 
 #include "gui/mixdevicewidget.h"
@@ -50,30 +47,27 @@ public:
 	       QWidget* parent, ViewBase* view, ProfControl* pctl);
     ~MDWEnum();
 
-    void addActionToPopup( KAction *action );
+    void addActionToPopup( QAction *action );
     QSizePolicy sizePolicy() const;
-    bool eventFilter( QObject* obj, QEvent* e );
+    bool eventFilter( QObject* obj, QEvent* e ) Q_DECL_OVERRIDE;
 
 public slots:
     // GUI hide and show
-    void setDisabled(bool);
+    void setDisabled(bool) Q_DECL_OVERRIDE;
 
     // Enum handling: next and selecting
     void nextEnumId();
     int  enumId();
     void setEnumId(int value);
 
-    void update();
-    virtual void showContextMenu(const QPoint& pos = QCursor::pos());
-
-signals:
-    virtual void guiVisibilityChange(MixDeviceWidget* source, bool enable);
+    void update() Q_DECL_OVERRIDE;
+    void showContextMenu(const QPoint& pos = QCursor::pos()) Q_DECL_OVERRIDE;
 
 private:
     void createWidgets();
 
     QLabel        *_label;
-    KComboBox     *_enumCombo;
+    QComboBox     *_enumCombo;
     QBoxLayout    *_layout;
 };
 
